@@ -1,4 +1,5 @@
 """Test sandboxjs.py and related code."""
+
 import logging
 import os
 import shutil
@@ -64,7 +65,7 @@ def hide_nodejs(temp_dir: Path) -> str:
                     os.symlink(os.path.join(dirname, entry), new_dir / entry)
             paths.append(str(new_dir))
             dirname_path = Path(dirname)
-            for path in paths:
+            for path in list(paths):
                 if Path(path).resolve() == dirname_path:
                     paths.remove(path)
     return ":".join(paths)
